# !/usr/bin/env python
# -*-coding:utf-8 -*-

"""
# File       : thread.py
# Time       ：22/4/18 20:24
# Author     ：Lex
# HomePage   : lexgeeker.com
# Email      : 2983997560@qq.com
# Description：
"""


class MyThread:
    def __init__(self, target=None, args=None, kwargs=None):
        pass

    def pause(self, *args, **kwargs):
        pass

    def resume(self, *args, **kwargs):
        pass

    def run(self, *args, **kwargs):
        pass

    def stop(self, *args, **kwargs):
        pass

    handle = None
